from acceldata_sdk.torch_client import TorchClient
import test_constants as test_const
from acceldata_sdk.models.pipeline import CreatePipeline, PipelineMetadata, PipelineRunResult, PipelineRunStatus
import pprint
from datetime import datetime
from acceldata_sdk.models.job import CreateJob, JobMetadata, Node
from acceldata_sdk.events.generic_event import GenericEvent


pp = pprint.PrettyPrinter(indent=4)

pipeline_uid = test_const.pipeline_uid
pipeline_name_ = test_const.pipeline_uid
job_uid = test_const.job_uid
torch_client = TorchClient(**test_const.torch_credentials)


def test_create_pipeline():
    meta = PipelineMetadata(owner='sdk/pipeline-user', team='TORCH', codeLocation='...')
    pipeline = CreatePipeline(
        uid=pipeline_uid,
        name=pipeline_name_,
        description=f'The pipeline {pipeline_name_} has been created from torch-sdk',
        meta=meta,
        context={'pipeline_uid': pipeline_uid, 'pipeline_name': pipeline_name_}
    )
    pipeline_res = torch_client.create_pipeline(pipeline=pipeline)
    pipeline = torch_client.get_pipeline(pipeline_res.id)
    assert pipeline is not None


def test_create_pipeline_run():
    pipeline = torch_client.get_pipeline(pipeline_uid)
    pipeline_run = pipeline.create_pipeline_run()
    run_with_id = pipeline.get_run(pipeline_run.id)
    assert pipeline_run == run_with_id


def test_latest_pipeline_run():
    pipeline = torch_client.get_pipeline(pipeline_uid)
    latest_run = pipeline.get_latest_pipeline_run()
    pipeline_runs = pipeline.get_runs()
    assert latest_run == pipeline_runs[0]


def test_update_pipeline_run():
    pipeline = torch_client.get_pipeline(pipeline_uid)
    latest_run = pipeline.get_latest_pipeline_run()
    update_pipeline_run_res = latest_run.update_pipeline_run(
        context_data={'key1': 'value2', 'name': 'backend'},
        result=PipelineRunResult.SUCCESS,
        status=PipelineRunStatus.COMPLETED
    )
    assert update_pipeline_run_res is not None


def test_details_pipeline_run():
    pipeline = torch_client.get_pipeline(pipeline_uid)
    latest_run = pipeline.get_latest_pipeline_run()
    details = latest_run.get_details()
    assert details is not None


def test_create_job():
    inputs = [Node(job_uid='customers.data-generation')]
    outputs = [Node(asset_uid=f'S3-DS.s3_customers')]
    context_job = {'job': 'data_gene', 'time': str(datetime.now()), 'uid': 'customers.data-generation',
                       'operator': 'write_file_func'}
    metadata = JobMetadata('Jason', 'COKE', 'https://github.com/coke/reports/customers.kt')
    pipeline = torch_client.get_pipeline(pipeline_uid)
    latest_run = pipeline.get_latest_pipeline_run()
    job = CreateJob(
        uid=job_uid,
        name=f'{job_uid} Job',
        version=latest_run.versionId,
        description=f'{job_uid} created using torch SDK',
        inputs=inputs,
        outputs=outputs,
        meta=metadata,
        context=context_job
    )
    job = pipeline.create_job(job)
    assert job is not None


def test_create_root_span():
    pipeline = torch_client.get_pipeline(pipeline_uid)
    latest_run = pipeline.get_latest_pipeline_run()
    span = latest_run.create_span(uid=f'{pipeline_uid}.span')
    assert span is not None


def test_create_child_span():
    pipeline = torch_client.get_pipeline(pipeline_uid)
    latest_run = pipeline.get_latest_pipeline_run()
    span_root = latest_run.get_root_span()
    span_child = span_root.create_child_span(
            uid=f'{job_uid}.span',
            context_data={
                'time': str(datetime.now())
            },
            associatedJobUids=[job_uid])
    span_child.start()
    span_child.send_event(GenericEvent(
        context_data={'client_time': str(datetime.now()), 'total_file': 1,
                      'schema': 'name,address,dept_id'},
        event_uid="customers.data.generation.metadata"))
    span_child.end()
    span_root.end()
    if span_root.is_root():
        query_span_id = latest_run.get_span(span_child.span.id)
        child_spans = span_root.get_child_spans()
        assert query_span_id.span == child_spans[0]


def test_spans_pipeline_run():
    pipeline = torch_client.get_pipeline(pipeline_uid)
    latest_run = pipeline.get_latest_pipeline_run()
    spans = latest_run.get_spans()
    assert spans is not None


def test_delete_pipeline():
    pipeline = torch_client.get_pipeline(pipeline_uid)
    delete_res = pipeline.delete()
    assert delete_res is not None



import os
# UID of the pipeline in torch
pipeline_uid = "torch.test"
# Name of the pipeline in torch
pipeline_name = "Integration test pipeline"
job_uid = "test_job"


# setup these 3 env vars in your environment.
# torch_credentials = {
#     'url': os.getenv('TORCH_CATALOG_URL', 'https://torch.acceldata.local:5443/torch'),
#     'access_key': os.getenv('TORCH_ACCESS_KEY', 'P04IM8FNQRUCRTU'),
#     'secret_key': os.getenv('TORCH_SECRET_KEY', 'E6LL9YUPMG4BDTJHT2VZD75HW0B8E5')
# }

torch_credentials = {
    'url': os.getenv('TORCH_CATALOG_URL', 'https://acceldata.dev.10.90.3.89.nip.io'),
    'access_key': os.getenv('TORCH_ACCESS_KEY', '21DK0CVJUAE0LET'),
    'secret_key': os.getenv('TORCH_SECRET_KEY', '1PT5E06TLCHKGELZCOEC7LLOCPYHJO')
}

ds_name = 'sf_ds'
ds_id = '1'
asset_uid = 'sf_ds.FINANCE.FINANCE.ACCELDATA_CUSTOMERS_IND'
asset_id = 4
dq_policy_id = 1
recon_policy_id = 3



from time import sleep

from models.connection import CreateConnection
from acceldata_sdk.models.profile import ProfilingType, JobType
from models.tags import ClassificationConfig
from acceldata_sdk.models.create_asset import AssetMetadata
from torch_client import TorchClient
from acceldata_sdk.models.datasource import CreateDataSource, DatasourceType, ConfigProperty, CrawlerStatus

torch_client = TorchClient(url="https://host5:5443",
                           access_key="185SF1I1G5LC", secret_key="vTGzcTbXYvIhbeKGj4Zsk3KNQPbQTK")

datasource_name = 'SNOWFLAKE_DATASOURCE_SDK'
datasource_details = torch_client.get_datasource(datasource_name)
asset_uid = datasource_name + ".CUSTOMERS_DATABASE.CUSTOMERS.CUSTOMERS"
asset = datasource_details.get_asset(asset_uid)
print(asset)

asset.add_asset_labels(labels=['alias:customers sdk'])

asset.add_asset_tag('custom_sdk_tag')
asset.add_asset_tag('my_tag')
profile_res = asset.start_profile(profiling_type=ProfilingType.FULL, job_type=JobType.PROFILE)
# asset.start_profile(profiling_type= ProfilingType.SAMPLE, job_type=JobType.MINI_PROFILE)
# profile_status = dict(dict(profile_res.get_status()).get('profileRequest')).get('status')
# print(profile_req_details)
# sleep(20)
# profile_req_details = dict(profile_res.get_status()).get('status')
# print(profile_req_details)

profile_status = dict(dict(profile_res.get_status()).get('profileRequest')).get('status')
while profile_status == 'IN PROGRESS':
    print('customer asset profiling in progress')
    sleep(3)
    profile_status = dict(dict(profile_res.get_status()).get('profileRequest')).get('status')
profile_status = dict(dict(profile_res.get_status()).get('profileRequest')).get('status')
print(profile_status)


from acceldata_sdk.events.span_event import SpanEvent


class GenericEvent(SpanEvent):
    """
        Description:
            Class to send any custom event to Torch. `event_uid` should be set
            here and the context data.
    """

    def __init__(self, event_uid, context_data=None):
        self.context_data = context_data
        self.event_uid = event_uid



from faker import Faker, Factory
from random import randint, choices
import string
import datetime
import snowflake.connector


def create_conn():
    conn = snowflake.connector.connect(
        user='winash',
        password='myD33ksh@k@n@lu',
        account='kf71436.us-east-1',
        warehouse='COMPUTE_WH',
        database='CUSTOMERS_DATABASE',
        schema='CUSTOMERS'
    )
    return conn


def create_cust_trans():
    trans = []
    fake = Faker()
    product_type = ['Industrial', 'row materials', 'electronics', 'softwares', 'books']
    success = [True, False]

    for i in range(1, 10):
        tr = {
            'customer_name': fake.name(),
            'transaction_id': ''.join(choices(string.ascii_uppercase, k=3)) + ''.join(choices(string.digits, k=5)),
            'merchant_name': fake.company(),
            'product_type': product_type[randint(0, 4)],
            'amount': randint(100, 10000),
            'transaction_at': datetime.datetime.now() + datetime.timedelta(minutes=randint(1, 20)),
            'success': success[randint(0, 1)]
        }
        trans.append(tr)
    return trans


def generate_transactions_data():
    insert_sql = """INSERT INTO CUSTOMERS_DATABASE.CUSTOMERS.CUSTOMERS_TRANSACTIONS (CUSTOMER_NAME, 
    TRANSACTIONS_ID, MERCHANT_NAME, AMOUNT, PRODUCT_TYPE, TRANSACTION_AT, SUCCESS) VALUES(%s, %s, %s, %s, %s, %s, %s); """

    trans = create_cust_trans()
    conn = create_conn()
    cur = conn.cursor()

    for tr in trans:
        cur.execute(insert_sql, (
            tr['customer_name'], tr['transaction_id'], tr['merchant_name'], tr['amount'], tr['product_type'],
            tr['transaction_at'], tr['success'],))

    conn.commit()


def generate_data():
    print('Generating data')
    generate_transactions_data()


# generate_data()
a = datetime.datetime(2021, 6, 22, 14, 10, 0)
b = datetime.datetime.today()

print(a, '  ', b)


from time import sleep

from acceldata_sdk.models.connection import CreateConnection
from acceldata_sdk.models.profile import ProfilingType, JobType
from acceldata_sdk.torch_client import TorchClient
from acceldata_sdk.models.datasource import CreateDataSource, DatasourceType, ConfigProperty, CrawlerStatus

# initiate torch client using api keys
torch_client = TorchClient(url="https://host5:5443",
                           access_key="185SF1I1G5LC", secret_key="vTGzcTbXYvIhbeKGj4Zsk3KNQPbQTK")

# configurations static names
connection_type = 'SNOWFLAKE'
connection_name = 'snowflake_connection'
datasource_name = 'SNOWFLAKE_DATASOURCE_SDK'

snowflake_connection_type_id = None
source_type_id = None
customer_rule_id = 1004

# fetch source and connection type data
for source_type in torch_client.get_all_source_types():
    if source_type.name == connection_type:
        source_type_id = source_type.id
        snowflake_connection_type_id = source_type.connectionTypeId

# fetch analysis pipeline id
analytics_pipeline_id = None
for pipeline in torch_client.list_all_analysis_pipelines():
    if pipeline.name == 'Default':
        analytics_pipeline_id = pipeline.id

create_conn_obj = CreateConnection(
    name=connection_name,
    description='snowflake connection from sdk',
    connection_type_id=snowflake_connection_type_id,
    analytics_pipeline_id=analytics_pipeline_id,
    properties=[ConfigProperty(key='jdbc.url', value='jdbc:snowflake://kf71436.us-east-1.snowflakecomputing.com'),
                ConfigProperty(key='jdbc.user', value='winash'),
                ConfigProperty(key='jdbc.password', value='myD33ksh@k@n@lu')]
)

# test connection
check_conn_status = torch_client.check_connection(create_conn_obj)

if check_conn_status.status == 'SUCCESS':
    print('Snowflake test connection succeed')
    # create a connection
    connection_details = torch_client.create_connection(create_conn_obj)
    print('Snowflake connection created successfully.')
    datasource = CreateDataSource(
        name=datasource_name,
        sourceType=DatasourceType(source_type_id, connection_type),
        description='Datasource snowflake from sdk',
        connectionId=connection_details.id,
        configProperties=[ConfigProperty(key='jdbc.warehouse', value='COMPUTE_WH'),
                          ConfigProperty(key='databases.0', value='CUSTOMERS_DATABASE')]
    )
    datasource_details = torch_client.create_datasource(datasource)
    print('Snowflake datasource created successfully.')

    # start a crawler
    datasource_details.start_crawler()
    sleep(10)

    # get crawler status
    crawler_status: CrawlerStatus = datasource_details.get_crawler_status()
    while crawler_status.status == 'Running':
        print('Snowflake - Crawler running .....')
        sleep(30)
        crawler_status: CrawlerStatus = datasource_details.get_crawler_status()
    sleep(5)
    print('Crawling of snowflake datasource completed successfully.')

    # get an asset
    asset_uid = datasource_name + ".CUSTOMERS_DATABASE.CUSTOMERS.CUSTOMERS"
    asset = datasource_details.get_asset(asset_uid)
    print('Updating customer asset details : tags, labels, annotation.')

    # add asset tags
    asset.add_asset_tag('SDK_CUSTOMER')
    asset.add_asset_tag('AD_CUSTOMERS')

    # add asset alias and annotation
    asset.add_asset_labels(labels=['alias:CUSTOMERS SDK', 'team:torch', 'owner:joe'])
    annotation = asset.update_asset_annotation(annotation='This is the customer asset contains details of the '
                                                          'acceldata customers.')
    # sample an asset
    sample_data = asset.sample_data()

    # profile an asset
    profile_res = asset.profile_asset(profiling_type=ProfilingType.FULL, job_type=JobType.PROFILE)
    profile_status = dict(dict(profile_res.get_status()).get('profileRequest')).get('status')
    while profile_status == 'IN PROGRESS':
        print('Customer asset profiling in progress .....')
        sleep(3)
        profile_status = dict(dict(profile_res.get_status()).get('profileRequest')).get('status')
    print('Customer asset profiling completed successfully.')

    # execute dq rule
    customer_dq_rule = torch_client.execute_dq_rule(rule_id=customer_rule_id, incremental=False)
    while 1:
        customer_dq_execution_details = torch_client.get_dq_rule_execution_details(execution_id=customer_dq_rule.id)
        print('Checking execution result of customer data quality rule .....')
        if customer_dq_execution_details.execution.executionStatus == 'SUCCESSFUL' and customer_dq_execution_details.execution.resultStatus == 'SUCCESSFUL':
            print('Data quality rule is completed successfully for customer table.')
            break
        elif customer_dq_execution_details.execution.executionStatus == 'RUNNING' and customer_dq_execution_details.execution.resultStatus == 'RUNNING':
            sleep(5)
            continue
        else:
            raise Exception(f'Data quality rule is failed for customer table.')
    customer_dq_execution_details = torch_client.get_dq_rule_execution_details(execution_id=customer_dq_rule.id)
    print('Customer DQ Rule Execution Details: ', customer_dq_execution_details.__dict__)


else:
    print('Snowflake test connection has been failed. Kindly verify credentials')



from enum import Enum, auto
from dataclasses import dataclass
from typing import List


class ConnectionType:

    def __init__(self, id, type):
        self.id = id
        self.type = type

    def __eq__(self, other):
        return self.id == other.id

    def __repr__(self):
        return f"ConnectionType({self.__dict__})"


class SecretsManagerType(Enum):
    AWS_SECRETS_MANAGER = auto()


@dataclass
class SecretManagerConfiguration:
    name: str = None
    type: SecretsManagerType = None

    def __init__(self,
                 name: str = None,
                 type: SecretsManagerType = None, *args, **kwargs):
        self.name = name
        if isinstance(type, dict):
            self.type = SecretsManagerType(**type)
        else:
            self.type = type


@dataclass
class SecretManagerConfigurationWithOption:
    secretManagerConfig: List[SecretManagerConfiguration] = None
    defaultOption: bool = None

    def __init__(self,
                 secretManagerConfig: List[SecretManagerConfiguration] = None,
                 defaultOption: bool = None, *args, **kwargs):
        self.defaultOption = defaultOption
        self.secretManagerConfig = list()
        if secretManagerConfig is not None:
            for obj in secretManagerConfig:
                if isinstance(obj, dict):
                    self.secretManagerConfig.append(SecretManagerConfiguration(**obj))
                else:
                    self.secretManagerConfig.append(obj)


@dataclass
class LivyComputeConfig:
    isEnabled = None
    executorMemory = None
    executorCores = None
    numExecutors = None

    def __init__(self,
                 isEnabled: bool = None,
                 executorMemory: str = None,
                 executorCores=None,
                 numExecutors=None, *args, **kwargs):
        self.isEnabled = isEnabled
        self.executorMemory = executorMemory
        self.executorCores = executorCores
        self.numExecutors = numExecutors

    def __repr__(self):
        return f"LivyComputeConfig({self.__dict__})"


@dataclass
class DatabricksComputeConfig:
    isEnabled = None
    minWorkers = None
    maxWorkers = None
    clusterWorkerType = None
    clusterDriverType = None
    jobClusterType = None

    def __init__(self,
                 isEnabled: bool = None,
                 minWorkers=None,
                 maxWorkers=None,
                 clusterWorkerType: str = None,
                 clusterDriverType: str = None,
                 jobClusterType: str = None,
                 *args, **kwargs):
        self.isEnabled = isEnabled
        self.minWorkers = minWorkers
        self.maxWorkers = maxWorkers
        self.clusterWorkerType = clusterWorkerType
        self.clusterDriverType = clusterDriverType
        self.jobClusterType = jobClusterType

    def __repr__(self):
        return f"DatabricksComputeConfig({self.__dict__})"


@dataclass
class YunikornComputeConfig:
    isEnabled = None
    executorMemory = None
    executorCores = None
    minExecutors = None
    maxExecutors = None

    def __init__(self,
                 isEnabled: bool = None,
                 executorMemory: str = None,
                 executorCores=None,
                 minExecutors=None,
                 maxExecutors=None, *args, **kwargs):
        self.isEnabled = isEnabled
        self.executorMemory = executorMemory
        self.executorCores = executorCores
        self.minExecutors = minExecutors
        self.maxExecutors = maxExecutors


@dataclass
class PipelineComputeConfig:
    livy: LivyComputeConfig = None
    databricks: DatabricksComputeConfig = None
    yunikorn: YunikornComputeConfig = None

    def __init__(self,
                 livy: LivyComputeConfig = None,
                 databricks: DatabricksComputeConfig = None,
                 yunikorn: YunikornComputeConfig = None, *args, **kwargs):
        if isinstance(livy, dict):
            self.livy = LivyComputeConfig(**livy)
        else:
            self.livy = livy
        if isinstance(databricks, dict):
            self.databricks = DatabricksComputeConfig(**databricks)
        else:
            self.databricks = databricks
        if isinstance(yunikorn, dict):
            self.yunikorn = YunikornComputeConfig(**yunikorn)
        else:
            self.yunikorn = yunikorn

    def __repr__(self):
        return f"PipelineComputeConfig({self.__dict__})"


class PipelineType(Enum):
    ANALYSIS = auto()
    MONITOR = auto()
    QUERY_ANALYSIS = auto()


@dataclass
class ProcessMetrics:
    status = None
    reportingTime = None
    
    def __init__(self,
                 status=None,
                 reportingTime=None, *args, **kwargs):
        self.status = status
        self.reportingTime = reportingTime

    def __repr__(self):
        return f"ProcessMetrics({self.__dict__})"


@dataclass
class KubernetesMetrics:
    status = None
    reportingTime = None

    def __init__(self,
                 status=None,
                 reportingTime=None, *args, **kwargs):
        self.status = status
        self.reportingTime = reportingTime


@dataclass
class DataplaneHealthMetrics:
    reportingTime: str = None
    process: ProcessMetrics = None
    kubernetes: KubernetesMetrics = None

    def __init__(self,
                 reportingTime=None,
                 process: ProcessMetrics = None,
                 kubernetes: KubernetesMetrics = None, *args, **kwargs):
        self.reportingTime = reportingTime
        if isinstance(process, dict):
            self.process = ProcessMetrics(**process)
        else:
            self.process = process
        if isinstance(kubernetes, dict):
            self.kubernetes = KubernetesMetrics(**kubernetes)
        else:
            self.kubernetes = kubernetes

    def __repr__(self):
        return f"DataplaneHealthMetrics({self.__dict__})"


class AnalyticsPipeline:

    def __init__(self, id, name, createdAt, updatedAt, url, externalUrl, description, hbaseEnabled,
                 hdfsEnabled, hiveEnabled, secretsManagerConfiguration=None, measureResultFsType=None,
                 tenantId = None, pipelineComputeConfig=None, pipelineType=None, version=None,
                 statusReportInterval=None, status=None, lastStatusReportTime=None, healthReport=None,
                 sparkMajorVersion=None, parentPipelineId=None, helmTemplateValues=None, **kwargs):
        self.name = name
        self.createdAt = createdAt
        self.updatedAt = updatedAt
        self.url = url
        self.id = id
        self.externalUrl = externalUrl
        self.description = description
        self.hbaseEnabled = hbaseEnabled
        self.hdfsEnabled = hdfsEnabled
        self.hiveEnable = hiveEnabled
        if isinstance(secretsManagerConfiguration, dict):
            self.secretsManagerConfiguration = SecretManagerConfigurationWithOption(**secretsManagerConfiguration)
        else:
            self.secretsManagerConfiguration = secretsManagerConfiguration

        self.measureResultFsType = measureResultFsType
        self.tenantId = tenantId
        if isinstance(pipelineComputeConfig, dict):
            self.pipelineComputeConfig = PipelineComputeConfig(**pipelineComputeConfig)
        else:
            self.pipelineComputeConfig = pipelineComputeConfig
        if isinstance(pipelineType, dict):
            self.pipelineType = PipelineType(**pipelineType)
        else:
            self.pipelineType = pipelineType

        self.version = version
        self.statusReportInterval = statusReportInterval
        self.status = status,
        self.lastStatusReportTime = lastStatusReportTime
        if isinstance(healthReport, dict):
            self.healthReport = DataplaneHealthMetrics(**healthReport)
        else:
            self.healthReport = healthReport
        self.sparkMajorVersion = sparkMajorVersion
        self.parentPipelineId = parentPipelineId
        self.helmTemplateValues = helmTemplateValues

    def __eq__(self, other):
        return self.name == other.name

    def __repr__(self):
        return f"AnalyticsPipeline({self.__dict__})"


class ConfigProperty:

    def __init__(self, key, value, id=None, **kwargs):
        self.key = key
        self.value = value
        self.id = id

    def __eq__(self, other):
        return self.id == other.id

    def __repr__(self):
        return f"ConfigProperty({self.__dict__})"


class Connection:

    def __init__(self, name, connectionType, createdAt, updatedAt, analyticsPipeline, configuration, assemblyCount=0,
                 description=None, properties=None,
                 id=None, **kwargs):
        self.name = name
        self.configuration = configuration
        self.connectionType = connectionType
        self.createdAt = createdAt
        self.updatedAt = updatedAt
        self.assemblyCount = assemblyCount
        self.description = description
        self.id = id
        if isinstance(connectionType, dict):
            self.connectionType = ConnectionType(**connectionType)
        else:
            self.connectionType = connectionType
        if isinstance(analyticsPipeline, dict):
            self.analyticsPipeline = AnalyticsPipeline(**analyticsPipeline)
        else:
            self.analyticsPipeline = analyticsPipeline
        self.properties = list()
        if properties is not None:
            for obj in properties:
                if isinstance(obj, dict):
                    self.properties.append(ConfigProperty(**obj))
                else:
                    self.properties.append(obj)

    def __eq__(self, other):
        return self.name == other.name

    def __repr__(self):
        return f"Connection({self.__dict__})"


class ConnectionCheckStatus(Enum):
    SUCCESS = 1
    FAILURE = 2


class ConnectionCheck:

    def __init__(self, message, status, **kwargs):
        self.message = message
        self.status = status

    def __repr__(self):
        return f"ConnectionCheckResponse({self.__dict__})"



from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'Operating System :: OS Independent',
    'License :: OSI Approved :: Apache Software License',
    'Programming Language :: Python :: 3'
]

# description = None
# try:
#     import pypandoc
#     description = pypandoc.convert('README.md', 'rst')
# except (IOError, ImportError):
#     description = open('README.md').read()

# Change MIN_TORCH_BACKEND_VERSION_SUPPORTED in constants as well if needed while updating version here

setup(
    name='acceldata_sdk',
    version='2.5.0',
    description='Acceldata SDK.' + '\n\n' + open('README.txt').read(),
    long_description=open('README.md').read() + '\n\n' + open('DATASOURCE_README.md').read() + '\n\n'  + open('CHANGELOG.txt').read(),
    long_description_content_type="text/markdown",
    url='',
    author='acceldata',
    author_email='apisupport@acceldata.io',
    license='MIT License',
    classifiers=classifiers,
    keywords='acceldata-sdk',
    packages=find_packages(),
    install_requires=['requests', 'dataclasses', 'typing', 'requests-toolbelt', 'semantic-version']
)



class AssetType:

    def __init__(self, id=None, name=None, canProfile=None, canSample=None, *args, **kwargs):
        """
            Description:
                Asset type supported in torch. like table, views, database et cetera.
        :param id: Id of the asset type
        :param name: name of the type
        :param canProfile: true if we can profile that kind of assets else false
        :param canSample: true if we can sample the data else false
        """
        self.id = id
        self.name = name
        self.canSample = canSample
        self.canProfile = canProfile

    def __repr__(self):
        return f"AssetType({self.__dict__!r})"
